Class: Net::LDAP::Entry
- Inherits:
-
Object
- Object
- Net::LDAP::Entry
- Defined in:
- lib/devise_ldap_multiple.rb
Overview
Open this class to allow myhash to be read (the data in an object of this type is within this instance variable)
Instance Attribute Summary collapse
-
#myhash ⇒ Object
readonly
Returns the value of attribute myhash.
Instance Attribute Details
#myhash ⇒ Object (readonly)
Returns the value of attribute myhash.
13 14 15 |
# File 'lib/devise_ldap_multiple.rb', line 13 def myhash @myhash end |